@@ -1,6 +1,6 @@
 group.Taxa.box <- function(data, is.OTU=TRUE, rank="g", 
-                      taxa="", meta, meta.factor="",      
-                      cex.y=5, cex.x=5, RAM.theme=NULL, 
+                      taxa="", meta, meta.factor="",     
+                      cex.y=5, cex.x=5, cex.main=10, RAM.theme=NULL, 
                       col.pal=NULL, main="", 
                       file=NULL, ext=NULL, height=8, width=16) {
 
@@ -10,9 +10,9 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
   }
 
   # valide rank
-  rank.name  <-  .get.rank.name(rank, plural=TRUE)
-  rank_name  <-   .get.rank.name(rank)
-  rank_pat  <-  .get.rank.pat(rank)
+  rank.name <- .get.rank.name(rank, plural=TRUE)
+  rank_name <- .get.rank.name(rank)
+  rank_pat <- .get.rank.pat(rank)
   
   # get the groups
   if( !length(meta.factor)==1 ) {
@@ -58,7 +58,7 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
            stop ("Error: no taxa present in the otu table")
       }
 
-      tax.sel <- tax[, which(names(tax) %in% taxa)]
+      tax.sel <- tax[, which(names(tax) %in% taxa), drop=FALSE]
       nocap <- setdiff(taxa, names(tax.sel))
       if ( length(nocap) != 0 ) {
           warning(paste(length(nocap), " taxa are not in the ", label, " dataset", sep=""))
@@ -107,9 +107,9 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
    
     # relative abundance of each taxa among samples
     tax.sel <- tax.sel[match(rownames(meta), 
-                      rownames(tax.sel)) ,]
+                      rownames(tax.sel)) , , drop=FALSE]
     if ( identical(rownames(tax.sel), rownames(meta)) ) {
-        tax.sel.p  <-  decostand(tax.sel, "total", MARGIN=2)
+        tax.sel.p  <-  vegan::decostand(tax.sel, "total", MARGIN=2)
         tax.sel.p.fac  <-  cbind(tax.sel.p, meta[[meta.factor]])
         names(tax.sel.p.fac)[ncol(tax.sel.p.fac)] <- meta.factor
         # for calculate total.count
@@ -123,18 +123,18 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
     df.count  <-  tax.sel.fac
     df.ra  <-  tax.sel.p.fac
  
-    # melt by sample
+    # reshape2::melt by sample
     #if ( require("reshape2") ) {
     #  reshape2::melt
     #} else {
     #   stop("package 'reshape2' is required to use this function")
     #}
 
-    df.ra.m <- melt(cbind(df.ra, sample=rownames(df.ra)),
+    df.ra.m <- reshape2::melt(cbind(df.ra, sample=rownames(df.ra)),
                 variable.name=rank_name, value.name="RA")
     names(df.ra.m)[ncol(df.ra.m)-1] <- rank_name
     names(df.ra.m)[ncol(df.ra.m)] <- "RA"
-    df.count.m <- melt(cbind(df.count, sample=rownames(df.count)),
+    df.count.m <- reshape2::melt(cbind(df.count, sample=rownames(df.count)),
                 variable.name=rank_name, value.name="count")
 
     names(df.count.m)[ncol(df.count.m)-1] <- rank_name
@@ -165,6 +165,16 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
   all.taxa  <-  do.call("rbind", taxa.m)
   all.count  <-  do.call("rbind", total.count)
 
+  #return(list(all.taxa=all.taxa, all.count=all.count))
+  # reorder by total counts
+  all.count <- all.count[order(all.count$total, decreasing=FALSE),]
+  all.count[[rank_name]] <- factor(all.count[[rank_name]],
+                              levels=rev(levels(all.count[[rank_name]])), 
+                              ordered=TRUE)
+  all.taxa[[rank_name]] <- factor(all.taxa[[rank_name]],
+                              levels=levels(all.count[[rank_name]]), 
+                              ordered=TRUE)
+
   # plot title, default is "":
     title  <-  main
 
@@ -192,16 +202,20 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
       lab <- list()
       for ( j in 1:length(labels) ) {
           sel <- which(total.count[[labels[j]]][[rank_name]]==i)
-          lab[[labels[j]]] <- paste(labels[j], ":", 
-                   total.count[[labels[j]]]$total[sel], sep="")
+          #lab[[labels[j]]] <- paste(labels[j], ":", 
+          #         total.count[[labels[j]]]$total[sel], sep="")
+          lab[[labels[j]]] <- round(total.count[[labels[j]]]$total[sel], digits=0)
+
       }      
-      lab1 <- paste(unlist(lab), collapse="\n")
-      lab.lst[[i]] <- paste(i, "\n", lab1, sep="")
+      #lab1 <- paste(unlist(lab), collapse="\n")
+      #lab.lst[[i]] <- paste(i, "\n", lab1, sep="")
+      lab1 <- paste(unlist(lab), collapse=",")
+      lab.lst[[i]] <- paste(i, "(", lab1, ")", sep="")
   }
   lab2 <- unlist(lab.lst)
   
  # boxplot 
- p <- ggplot(all.taxa, aes_string(x=rank_name,
+ p <- ggplot2::ggplot(all.taxa, aes_string(x=rank_name,
             y="RA",fill=meta.factor)) + 
            geom_boxplot() 
 
@@ -211,19 +225,22 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
   # flip x & y
   p <- p +  scale_fill_manual(values=cols[names(cols) %in% 
                    levels(factor(all.taxa[[meta.factor]]))])+
-            scale_y_continuous(labels=percent_format()) + 
+            scale_y_continuous(labels=scales::percent_format()) + 
             xlab(.capitalize(.get.rank.name(rank))) +
             ylab("Percentage") + 
             coord_flip() +
             ggtitle(title) 
 
   if ( is.null(RAM.theme) ) {     
-     p <- p + theme(legend.key.size=unit(6,"mm"), 
+     p <- p + theme(legend.key.size=grid::unit(6,"mm"), 
               legend.text = element_text(size=10),
-              plot.title = element_text(face="bold"),
-              axis.text.y=element_text(size=cex.y),
-              axis.text.x=element_text(size=cex.x),
-              legend.position="right") 
+              axis.text.y=element_text(size=cex.y, face="bold"),
+              axis.text.x=element_text(size=cex.x, face="bold"),
+              #axis.ticks.length=grid::unit(-0.1, "cm"), 
+              #axis.ticks.margin=grid::unit(0.5, "cm"),
+              axis.ticks.y=element_line(size=1),
+              legend.position="right",
+              plot.title = element_text(face="bold", size=cex.main))
   } else {
     p <- p + RAM.theme
   } 
@@ -240,15 +257,16 @@ group.Taxa.box <- function(data, is.OTU=TRUE, rank="g",
 
 
 group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="", 
-                        meta, meta.factor="", cex.y=5, cex.x=5, 
-                        bar.width=NULL, RAM.theme=NULL,
-                        col.pal=NULL, main="", file=NULL, ext=NULL, 
+                        meta, meta.factor="", func="sum", cex.y=5, 
+                        cex.x=5, cex.main=10, bar.width=NULL, 
+                        RAM.theme=NULL, col.pal=NULL, main="", 
+                        file=NULL, ext=NULL, 
                         height=8, width=16) {
 
   # valide rank
-  rank.name  <-  .get.rank.name(rank, plural=TRUE)
-  rank_name  <-   .get.rank.name(rank)
-  rank_pat  <-  .get.rank.pat(rank)
+  rank.name <- .get.rank.name(rank, plural=TRUE)
+  rank_name <- .get.rank.name(rank)
+  rank_pat <- .get.rank.pat(rank)
 
   # check whether data is list
   if ( !is.list(data) ) {
@@ -256,7 +274,7 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
   }
 
   # get the groups
-  .valid.factor(meta, meta.factor)
+  .valid.factors(meta, meta.factor)
   if(!length(meta.factor)==1) {
      stop ("Error: please provide one factor")
   }
@@ -293,7 +311,7 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
            stop ("Error: no taxa present in the otu table")
       }
 
-      tax.sel <- tax[, which(names(tax) %in% taxa)]
+      tax.sel <- tax[, which(names(tax) %in% taxa), drop=FALSE]
       nocap <- setdiff(taxa, names(tax.sel))
       if ( length(nocap) != 0 ) {
           warning(paste(length(nocap), " taxa are not in the ", label, " dataset", sep=""))
@@ -324,8 +342,8 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
   # process the tax.abund matrices
   taxa.m <- list()
   total.count <- list()
+  
   for (i in 1:length(tax.list)) {
-    
     label <- names(tax.list)[i]
     tax <- tax.list[[i]] 
     if ( is.null(tax) ) { break }
@@ -340,12 +358,12 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
     rownames(df) <- rownames(tax)     
     tax.sel <- df
 
-    tax.sel.fac <- aggregate(tax.sel, 
-                   by=list(meta[[meta.factor]]), FUN=sum)
+    tax.sel.fac <- stats::aggregate(tax.sel, by=list(meta[[meta.factor]]), FUN=func)
+   
     rownames(tax.sel.fac) <- tax.sel.fac$Group.1
-    tax.sel.fac<-as.data.frame(tax.sel.fac[,-1])
+    tax.sel.fac<-as.data.frame(tax.sel.fac[,-1, drop=FALSE])
 
-    # melt by factor
+    # reshape2::melt by factor
     #if (!require("reshape2")) {
     #   stop("package 'reshape2' is required to use this function")
     #}
@@ -382,6 +400,17 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
    
   all.taxa  <-  do.call("rbind", taxa.m)
   all.count  <-  do.call("rbind", total.count)
+
+  # reorder by total counts
+  all.count$total <- round(all.count$total, digits=0)
+  #all.count <- all.count[order(all.count$total, decreasing=FALSE),]
+  all.count[[rank_name]] <- factor(all.count[[rank_name]],
+                              levels=rev(levels(all.count[[rank_name]])), 
+                              ordered=TRUE)
+  all.taxa[[rank_name]] <- factor(all.taxa[[rank_name]],
+                              levels=levels(all.count[[rank_name]]), 
+                              ordered=TRUE)
+
   #return(list(all.taxa, all.count))
   title = main
 
@@ -410,22 +439,27 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
       lab <- list()
       for ( j in 1:length(labels) ) {
           sel <- which(total.count[[labels[j]]][[rank_name]]==i)
-          lab[[labels[j]]] <- paste(labels[j], ":", 
-                   total.count[[labels[j]]]$total[sel], sep="")
+          #lab[[labels[j]]] <- paste(labels[j], ":", 
+          #         total.count[[labels[j]]]$total[sel], sep="")
+          lab[[labels[j]]] <- round(total.count[[labels[j]]]$total[sel], digits=0)
+
       }      
-      lab1 <- paste(unlist(lab), collapse="\n")
-      lab.lst[[i]] <- paste(i, "\n", lab1, sep="")
+      #lab1 <- paste(unlist(lab), collapse="\n")
+      #lab.lst[[i]] <- paste(i, "\n", lab1, sep="")
+      lab1 <- paste(unlist(lab), collapse=",")
+      lab.lst[[i]] <- paste(i, "(", lab1, ")", sep="")
   }
   lab2 <- unlist(lab.lst)
+
   
  # barplot 
  if ( is.null(bar.width) ) {
-    p <- ggplot(all.taxa, aes_string(x=rank_name,
+    p <- ggplot2::ggplot(all.taxa, aes_string(x=rank_name,
             y="count",fill=meta.factor)) + 
            geom_bar(colour="white",stat="identity",
              position="fill") 
  } else {
-   p <- ggplot(all.taxa, aes_string(x=rank_name,
+   p <- ggplot2::ggplot(all.taxa, aes_string(x=rank_name,
             y="count",fill=meta.factor)) + 
            geom_bar(width=bar.width, colour="white",stat="identity",
              position="fill")
@@ -434,7 +468,7 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
   # facet by region,   # flip x & y
   p <- p + scale_fill_manual(values=cols[names(cols) %in% 
                    levels(factor(all.taxa[[meta.factor]]))]) +
-           scale_y_continuous(labels=percent_format()) +
+           scale_y_continuous(labels=scales::percent_format()) +
            scale_x_discrete(labels = lab2) + 
            facet_wrap(~Region) + 
            ggtitle(title) +
@@ -444,12 +478,16 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
            
 
   if ( is.null(RAM.theme) ) {
-    p <- p + theme(legend.key.size=unit(6,"mm"), 
-                   axis.text.y=element_text(size=cex.y),
-                   axis.text.x=element_text(size=cex.x),
+    p <- p + theme(legend.key.size=grid::unit(6,"mm"), 
+                   axis.text.y=element_text(size=cex.y, face="bold"),
+                   axis.text.x=element_text(size=cex.x, face="bold"),
+                   #axis.ticks.length=grid::unit(-0.25, "cm"), 
+                   #axis.ticks.margin=grid::unit(0.5, "cm"),
+                   axis.ticks.y=element_line(size=0.5),
                    legend.position="right",
                    legend.text = element_text(size=10), 
-                   plot.title = element_text(face="bold"))
+                   plot.title = element_text(face="bold", size=cex.main),
+                   strip.text.x = element_text(size=8, face="bold", angle=0))
   } else {
     p <- p + RAM.theme
   } 
@@ -465,69 +503,69 @@ group.Taxa.bar <- function(data, is.OTU=TRUE, rank="g", taxa="",
 
 
 group.abund.Taxa <- function(data, is.OTU=TRUE, rank="g", taxa, 
-                        drop.unclassified=FALSE, bar.width=NULL,
-                        meta, meta.factor="", RAM.theme=NULL, 
-                        col.pal=NULL, main="",
-                        file=NULL, ext=NULL, height=8, width=16) {
- 
+                             drop.unclassified=FALSE, bar.width=NULL,
+                             meta, meta.factor="", RAM.theme=NULL, 
+                             col.pal=NULL, main="",
+                             file=NULL, ext=NULL, height=8, width=16) {
+  
   save <- !is.null(file)
   
   # valide rank
-  rank.name  <-  .get.rank.name(rank, plural=TRUE)
-  rank_name  <-   .get.rank.name(rank)
-  rank_pat  <-  .get.rank.pat(rank)
+  rank.name <- .get.rank.name(rank, plural=TRUE)
+  rank_name <- .get.rank.name(rank)
+  rank_pat <- .get.rank.pat(rank)
   
   # get the groups
   if( !length(meta.factor)==1 || 
-      !any(names(meta) %in% meta.factor) ) {
+        !any(names(meta) %in% meta.factor) ) {
     stop ("Error: please provide one factor")
   } 
-
+  
   if( length(taxa)==0 || taxa=="" ) {
-     stop ("Error: please provide list of taxa or top# of groups to plot")
+    stop ("Error: please provide list of taxa or top# of groups to plot")
   }
-
- # check whether data is list
+  
+  # check whether data is list
   if ( !is.list(data) ) {
-      stop("Please provide input data as list, see ?RAM.input.formatting")
+    stop("Please provide input data as list, see ?RAM.input.formatting")
   }
-
+  
   # labels for each dataset
   labels <- names(data)
-
+  
   # process each data set  
   tax.list <- list()
   for (i in 1:length(data)) {
     if ( is.null(data[[i]]) ) {
       break
     }
-
+    
     label <- names(data)[i]
     elem <- data[[i]]
-
+    
     if ( is.OTU ) {
       valid.OTU(elem)
-       # get the groups
+      # get the groups
       tax<-.group.rank2(data=elem, meta=meta, 
                         meta.factor=meta.factor,
-                       relative.abund=TRUE, taxa=taxa,  
-                       drop.unclassified=drop.unclassified, 
-                       rank=rank)  
+                        relative.abund=TRUE, taxa=taxa,  
+                        drop.unclassified=drop.unclassified, 
+                        rank=rank)  
     } else {
-      elem.p <- decostand(elem, "total")
+      elem.p <- vegan::decostand(elem, "total")
       tax <- elem.p[, names(elem.p) %in% taxa]
     }
-     
-    # melt by Sample
+    
+    # reshape2::melt by Sample
     #if (!require("reshape2")) {
-   #   stop("package 'reshape2' is required to use this function")
-   # }
-    if (ncol(tax) ==0 ) { 
+    #   stop("package 'reshape2' is required to use this function")
+    # }
+    if (ncol(tax) == 0 ) { 
       stop("selected taxa was not found")
     }
-    tax.m <- melt(cbind(tax, Sample=rownames(tax)), 
-                       id.vars="Sample", value.name="RA", 
-                       variable.name=rank_name)
+    tax.m <- reshape2::melt(cbind(tax, Sample=rownames(tax)), 
+                            id.vars="Sample", value.name="RA", 
+                            variable.name=rank_name)
     names(tax.m)[ncol(tax.m)-1] <- rank_name
     names(tax.m)[ncol(tax.m)] <- "RA"
     # bind together with appropriate label
@@ -541,57 +579,57 @@ group.abund.Taxa <- function(data, is.OTU=TRUE, rank="g", taxa,
   # reorder levels based on order of appearance in table
   all.taxa$Sample <- ordered(all.taxa$Sample, levels=unique(all.taxa$Sample))
   
-    title <- main
+  title <- main
   
- # if ( !require("scales") ) {
- #     stop("package 'scales' is required for this function")
- # }
- # if ( !require("RColorBrewer") ) {
- #     stop("package 'RColorBrewer' is required for this function")
- # }
- # if ( !require("grid") ) {
-#      stop("package 'grid' is required for this function")
- # }
-
+  # if ( !require("scales") ) {
+  #     stop("package 'scales' is required for this function")
+  # }
+  # if ( !require("RColorBrewer") ) {
+  #     stop("package 'RColorBrewer' is required for this function")
+  # }
+  # if ( !require("grid") ) {
+  #      stop("package 'grid' is required for this function")
+  # }
+  
+  
+  # use actual colours
+  cols.needed <- length(unique(all.taxa[[rank_name]]))
+  cols <- .cols(cols.needed=cols.needed, col.pal)
+  names(cols) <- levels(factor(all.taxa[[rank_name]])) 
   
-   # use actual colours
-   cols.needed <- length(unique(all.taxa[[rank_name]]))
-   cols <- .cols(cols.needed=cols.needed, col.pal)
-   names(cols) <- levels(factor(all.taxa[[rank_name]])) 
-    
   # we need to use aes_string to pass CRAN check; see 
   # http://goo.gl/JxgZ9u
   if ( is.null(bar.width) ) {
-    p <- ggplot(all.taxa, aes_string(x="Sample", y="RA", 
-              fill=rank_name)) + 
-         geom_bar(position="stack", stat="identity") 
+    p <- ggplot2::ggplot(all.taxa, aes_string(x="Sample", y="RA", 
+                                     fill=rank_name)) + 
+      geom_bar(position="stack", stat="identity") 
   } else {
-    p <- ggplot(all.taxa, aes_string(x="Sample", y="RA", 
-              fill=rank_name)) + 
-         geom_bar(position="stack", stat="identity", width=bar.width)
+    p <- ggplot2::ggplot(all.taxa, aes_string(x="Sample", y="RA", 
+                                     fill=rank_name)) + 
+      geom_bar(position="stack", stat="identity", width=bar.width)
   }
   
   if ( is.null(RAM.theme) ) {
     p <- p + theme(legend.position="bottom", 
                    axis.text.x=element_text(angle = 45, vjust = 1,  
-                                hjust=1),
+                                            hjust=1),
                    panel.grid.major.x = element_blank())
   } else {
     p <- p + RAM.theme
   } 
-    #coord_flip() +
-  p <- p +  scale_y_continuous(labels = percent_format()) +
-            facet_wrap(~Region, scales="free_x") +
-            xlab(meta.factor) +
-            ylab("Relative Abundance") + 
-            ggtitle(title)+
-            scale_fill_manual(values=cols[names(cols) %in% 
-                   levels(factor(all.taxa[[rank_name]]))], 
-            guide=guide_legend(direction="horizontal", ncol=5))+
-            theme(legend.position="bottom") 
-            
-    
- .valid.plot.settings(file, ext)
+  #coord_flip() +
+  p <- p +  scale_y_continuous(labels = scales::percent_format()) +
+    facet_wrap(~Region, scales="free_x") +
+    xlab(meta.factor) +
+    ylab("Relative Abundance") + 
+    ggtitle(title)+
+    scale_fill_manual(values=cols[names(cols) %in% 
+                                    levels(factor(all.taxa[[rank_name]]))], 
+                      guide=ggplot2::guide_legend(direction="horizontal", ncol=5))+
+    theme(legend.position="bottom") 
+  
+  
+  .valid.plot.settings(file, ext)
   save <- !is.null(file)
   if (save) {
     .ggsave.helper(file, ext, width, height, plot=p)
@@ -601,14 +639,14 @@ group.abund.Taxa <- function(data, is.OTU=TRUE, rank="g", taxa,
   
 }
 
-shared.Taxa <- function(data, is.OTU=TRUE, rank="g") {
 
+shared.Taxa <- function(data, is.OTU=TRUE, rank="g") {
   .valid.data(data=data, is.OTU=is.OTU)
-   # valide rank
+  # valide rank
   if ( is.OTU ) {
-    rank.name  <-  .get.rank.name(rank, plural=TRUE)
-    rank_name  <-   .get.rank.name(rank)
-    rank_pat  <-  .get.rank.pat(rank)
+    rank.name <- .get.rank.name(rank, plural=TRUE)
+    rank_name <- .get.rank.name(rank)
+    rank_pat <- .get.rank.pat(rank)
   } else {
     warning("data are not otu tables, will ignore the rank provided")
     rank_name <- "taxa"
@@ -616,112 +654,112 @@ shared.Taxa <- function(data, is.OTU=TRUE, rank="g") {
     rank_pat <- ""
   }
   
- # check whether data is list
+  # check whether data is list
   if ( !is.list(data) ) {
-      stop("Please provide input data as list, see ?RAM.input.formatting")
+    stop("Please provide input data as list, see ?RAM.input.formatting")
   }
-
+  
   # labels for each dataset
   labels <- names(data)
-
+  
   # process each data set  
   shared.list <- list()
   for (i in 1:length(data)) {
-      if ( is.null(data[[i]]) ) {
-         break
-      }
-
-      label <- names(data)[i]
-      elem <- data[[i]]
-
-      if ( is.OTU ) {
-          valid.OTU(elem)
-          total.count <- sum(transpose.OTU(elem))
-          tax <- tax.abund(elem, rank=rank, drop.unclassified=TRUE, 
-                       count=TRUE)
-      } else {
-          total.count <- sum(elem)
-          tax <- elem
-      }
-
-      ###check for zero entries?
-      if(dim(tax)[2] == 1) {
-           stop(paste("Error: Only one taxon at the ", rank_name, " level! Please choose another taxonomic rank to compare", sep=""))
-      } else { 
-          tax.pa <- decostand(tax, "pa")
-      }
-
-      # for readability
-      x <- dim(tax.pa)[1] # number of samples
-      y <- dim(tax.pa)[2] # number of taxa
-  
-     if( length(which(colSums(tax.pa) == x ))==0 ) {
-          stop("NO taxa are shared by all samples")
-     } else {
-
-        num.tax.one.sample <- dim(tax.pa[ ,colSums(tax.pa) == 1])[2]
-        num.tax.mult.sample <- dim(tax.pa[ ,colSums(tax.pa) > 1])[2] 
-        ### test this
-        num.tax.all.sample <- dim(tax.pa[ ,colSums(tax.pa) == x])[2]
-  
-        per.tax.one.sample <- num.tax.one.sample / y
-        per.tax.all.sample <- num.tax.all.sample / y
-  
-        num.seq.shared.tax <- sum(tax[ , colnames(tax) %in% 
-                     names(tax.pa)[which(colSums(tax.pa) == x)]])
-        per.seq.shared.tax <- num.seq.shared.tax / total.count
-      # get the taxa names for all taxs present in all samples
-        tax <- names(tax.pa)[which(colSums(tax.pa) == x)]
-    
-      }
-  
-      val <- list(num.tax.one.sample, num.tax.mult.sample, 
-                  num.tax.all.sample, per.tax.one.sample, 
-                  per.tax.all.sample, num.seq.shared.tax,
-                  per.seq.shared.tax, tax)
-  
-  # format numerical data?
-  #val <- format(round(val[1:7], 2), nsmall=2)
-  
-      names(val) <- c(paste("#_of_", rank.name, "_in_1_sample", sep=""), 
-               paste("#_of_", rank.name, "_in_>1_sample", sep=""), 
-               paste("#_of_", rank.name, "_in_all_samples", sep=""),
-               paste("%_of_", rank.name, "_in_one_sample", sep=""),
-               paste("%_of_", rank.name, "_in_all_samples", sep=""), 
-               paste("#_of_sequence_in_shared_", rank.name, sep=""),
-               paste("%_of_sequence_in_shared_", rank.name, sep=""), 
-               paste(rank.name, "_in_all_samples", sep=""))
-
-      shared.list[[label]] <- val
+    if ( is.null(data[[i]]) ) {
+      break
     }
+    
+    label <- names(data)[i]
+    elem <- data[[i]]
+    
+    if ( is.OTU ) {
+      valid.OTU(elem)
+      total.count <- sum(transpose.OTU(elem))
+      tax <- tax.abund(elem, rank=rank, drop.unclassified=TRUE, 
+                       count=TRUE)
+    } else {
+      total.count <- sum(elem)
+      tax <- elem
+    }
+    
+    ###check for zero entries?
+    if(dim(tax)[2] == 1) {
+      stop(paste("Error: Only one taxon at the ", rank_name, " level! Please choose another taxonomic rank to compare", sep=""))
+    } else { 
+      tax.pa <- decostand(tax, "pa")
+    }
+    
+    # for readability
+    x <- dim(tax.pa)[1] # number of samples
+    y <- dim(tax.pa)[2] # number of taxa
+    
+    num.tax.one.sample <- dim(tax.pa[ ,colSums(tax.pa) == 1, drop=FALSE])[2]
+    num.tax.mult.sample <- dim(tax.pa[ ,colSums(tax.pa) > 1, drop=FALSE])[2] 
+    ### test this
+    num.tax.all.sample <- dim(tax.pa[ ,colSums(tax.pa) == x, drop=FALSE])[2]
+    
+    per.tax.one.sample <- num.tax.one.sample / y
+    per.tax.all.sample <- num.tax.all.sample / y
+    
+    if( length(which(colSums(tax.pa) == x ))==0 ) {
+      warning("NO taxa are shared by all samples")
+      num.seq.shared.tax <- 0
+    } else {
+      num.seq.shared.tax <- sum(tax[ , colnames(tax) %in% 
+                                      names(tax.pa)[which(colSums(tax.pa) == x)]])
+    }
+    per.seq.shared.tax <- num.seq.shared.tax / total.count
+    
+    # get the taxa names for all taxs present in all samples
+    tax <- names(tax.pa)[which(colSums(tax.pa) == x)]
+        
+    val <- list(num.tax.one.sample, num.tax.mult.sample, 
+                num.tax.all.sample, per.tax.one.sample, 
+                per.tax.all.sample, num.seq.shared.tax,
+                per.seq.shared.tax, tax)
+    
+    # format numerical data?
+    #val <- format(round(val[1:7], 2), nsmall=2)
+    
+    names(val) <- c(paste("#_of_", rank.name, "_in_1_sample", sep=""), 
+                    paste("#_of_", rank.name, "_in_>1_sample", sep=""), 
+                    paste("#_of_", rank.name, "_in_all_samples", sep=""),
+                    paste("%_of_", rank.name, "_in_one_sample", sep=""),
+                    paste("%_of_", rank.name, "_in_all_samples", sep=""), 
+                    paste("#_of_sequence_in_shared_", rank.name, sep=""),
+                    paste("%_of_sequence_in_shared_", rank.name, sep=""), 
+                    paste(rank.name, "_in_all_samples", sep=""))
+    
+    shared.list[[label]] <- val
+  }
   return(shared.list)
 }
 
 
 .cols <- function(cols.needed, col.pal=NULL) {
-   if ( is.null(col.pal) ) {    
-      if ( cols.needed <= 2 ) {
-          cols <- c("#E41A1C", "#377EB8")
-      } else if ( cols.needed <= 12 && cols.needed > 2 ) {
-          cols <- brewer.pal(cols.needed, "Set3")
-      } else {
-
-         # if palette max is 12; so if we have more than 6 entries for otu1/2, we 
-  # need to manually construct a palette to use
-  
-         #cols <- rainbow(cols.needed) 
-         col.func <- colorRampPalette(brewer.pal(12, "Set3"))
-         cols <- col.func(cols.needed)
-      } 
+  if ( is.null(col.pal) ) {    
+    if ( cols.needed <= 2 ) {
+      cols <- c("#E41A1C", "#377EB8")
+    } else if ( cols.needed <= 12 && cols.needed > 2 ) {
+      cols <- RColorBrewer::brewer.pal(cols.needed, "Set3")
+    } else {
+      
+      # if palette max is 12; so if we have more than 6 entries for otu1/2, we 
+      # need to manually construct a palette to use
+      
+      #cols <- rainbow(cols.needed) 
+      col.func <- grDevices::colorRampPalette(RColorBrewer::brewer.pal(12, "Set3"))
+      cols <- col.func(cols.needed)
+    } 
   } else {
-     cols <- col.pal
+    cols <- col.pal
   }
 }
         
 
 .group.rank2<-function(data, is.OTU=TRUE, meta=meta, meta.factor="",
                       drop.unclassified=FALSE, relative.abund=FALSE, 
-                      rank="g", taxa=NULL){
+                      rank="g", func="sum", taxa=NULL){
   ## whether data an OTU or taxonomic abundance matrix
   if ( is.OTU ) {
       valid.OTU(data)
@@ -738,17 +776,17 @@ shared.Taxa <- function(data, is.OTU=TRUE, rank="g") {
   } 
 
   if(all(rownames(tax)==rownames(meta))) {
-    tax.factor<-aggregate(tax, by=list(meta[[meta.factor]]), FUN=sum)
-    rownames(tax.factor)<-tax.factor[,"Group.1"]
-    tax.factor<-tax.factor[,-1]
+    tax.factor <- stats::aggregate(tax, by=list(meta[[meta.factor]]), FUN=func)
+    rownames(tax.factor) <- tax.factor[,"Group.1"]
+    tax.factor <- tax.factor[,-1]
   } else {
     stop("Error: otu and metadata have different samples")
   }
-  tax.factor<-tax.factor[, order(colSums(tax.factor), decreasing=TRUE)]
+  tax.factor <- tax.factor[, order(colSums(tax.factor), decreasing=TRUE)]
   if(!isTRUE(relative.abund)) {
-    tax.factor<-tax.factor
+    tax.factor <- tax.factor
   } else {
-    tax.factor<-decostand(tax.factor, "total")    
+    tax.factor <- vegan::decostand(tax.factor, "total")    
   }
   
   if (drop.unclassified) {
@@ -775,7 +813,7 @@ shared.Taxa <- function(data, is.OTU=TRUE, rank="g") {
       if( !any(names(tax.factor) %in% taxa) ) {
           stop ("Error: no taxa present in the dataset")
       } else {
-         tax.factor.sel <- tax.factor[, which(names(tax.factor) %in% taxa)]
+         tax.factor.sel <- tax.factor[, which(names(tax.factor) %in% taxa), drop=FALSE]
          nocap <- setdiff(taxa, names(tax.factor.sel))
          if ( length(nocap) != 0 ) {
              warning(paste("Taxa not in the dataset: ", paste(nocap, collapse=" ,"), sep=""))
